@@ -46,18 +46,20 @@ test_that("cite_* work with umlaute", {
   #      file = file_name, append = TRUE)
   worcs:::write_as_utf(c("", "Optional räference: @@reference2020"),
                        con = file_name, append = TRUE)
-  sink_out <- capture_output(cite_all(file_name))
-  md_file <- force(gsub("Rmd$", "md", file_name))
-  contents <- worcs:::read_as_utf(md_file)
+  if (rmarkdown::pandoc_available("1.12.3")){
+    sink_out <- capture_output(cite_all(file_name))
+    md_file <- force(gsub("Rmd$", "md", file_name))
+    contents <- worcs:::read_as_utf(md_file)
 
-  expect_true(any(contents == "Optional räference: @reference2020"))
+    expect_true(any(contents == "Optional räference: @reference2020"))
 
-  sink_out <- capture_output(cite_essential(file_name))
+    sink_out <- capture_output(cite_essential(file_name))
 
-  contents <- worcs:::read_as_utf(gsub("Rmd$", "md", file_name))
+    contents <- worcs:::read_as_utf(gsub("Rmd$", "md", file_name))
 
-  expect_true(!any(contents == "Optional räference: @reference2020"))
-  expect_true(any(contents == "Optional räference:"))
+    expect_true(!any(contents == "Optional räference: @reference2020"))
+    expect_true(any(contents == "Optional räference:"))
+  }
 })
 
 test_that("cite_* retain relative paths", {
@@ -87,19 +89,21 @@ myiris <- read.csv('iris.csv')
 "), file = file_name, append = TRUE)
 
   # Render with all citations
-  sink_out <- capture_output(cite_all(file_name))
+  if (rmarkdown::pandoc_available("1.12.3")){
+    sink_out <- capture_output(cite_all(file_name))
 
-  contents <- readLines(normalizePath(gsub("\\.Rmd", "\\.md", file_name)))
+    contents <- readLines(normalizePath(gsub("\\.Rmd", "\\.md", file_name)))
 
-  expect_true(any(contents == "Optional reference: @reference2020"))
+    expect_true(any(contents == "Optional reference: @reference2020"))
 
-  sink_out <- capture_output(cite_essential(file_name))
+    sink_out <- capture_output(cite_essential(file_name))
 
-  contents <- readLines(normalizePath(gsub("\\.Rmd", "\\.md", file_name)))
+    contents <- readLines(normalizePath(gsub("\\.Rmd", "\\.md", file_name)))
 
-  expect_true(!any(contents == "Optional reference: @reference2020"))
-  expect_true(any(grepl("myiris", contents, fixed = TRUE)))
-  expect_true(any(contents == "Optional reference:"))
+    expect_true(!any(contents == "Optional reference: @reference2020"))
+    expect_true(any(grepl("myiris", contents, fixed = TRUE)))
+    expect_true(any(contents == "Optional reference:"))
+  }
 })
 
 test_that("cite_* retain double @", {
